<?php

namespace Drupal\bpmn_io\Controller;

use Drupal\Component\Utility\Random;
use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\eca\Entity\Eca;
use Drupal\eca\ModellerServices;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class BpmnIo.
 *
 * @package Drupal\bpmn_io\Controller
 */
class BpmnIo extends ControllerBase {

  /**
   * @var \Drupal\Component\Uuid\UuidInterface
   */
  protected UuidInterface $uuid;

  /**
   * @var \Drupal\eca\ModellerServices
   */
  protected ModellerServices $modellerServices;

  /**
   * BpmnIo constructor.
   *
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   * @param \Drupal\eca\ModellerServices $modeller_services
   */
  public function __construct(UuidInterface $uuid, ModellerServices $modeller_services) {
    $this->uuid = $uuid;
    $this->modellerServices = $modeller_services;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): BpmnIo {
    return new static(
      $container->get('uuid'),
      $container->get('eca.service.modeller')
    );
  }

  public function add(): array {
    if ($modeller = $this->modellerServices->getModeller('bpmn_io')) {
      $random = new Random();
      $id = 'Process_' . $random->name(7);
      $emptyBpmn = file_get_contents(drupal_get_path('module', 'bpmn_io') . '/data/empty.bpmn');
      $emptyBpmn = str_replace([
        'SIDPLACEHOLDER1',
        'SIDPLACEHOLDER2',
        'IDPLACEHOLDER'
      ], [
        'sid-' . $this->uuid->generate(),
        'sid-' . $this->uuid->generate(),
        $id,
      ], $emptyBpmn);
      $eca = Eca::create(['id' => strtolower($id)]);
      $eca->getModel()->setModeldata($emptyBpmn);
      $modeller->setConfigEntity($eca);
      return $modeller->edit();
    }
    return [];
  }

}
